@@ -86,7 +86,7 @@
 #define KITEMVIEWS_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KITEMVIEWS_NO_DEPRECATED
-#  define KITEMVIEWS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x54c00
+#  define KITEMVIEWS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55200
 #endif
 #ifdef KITEMVIEWS_NO_DEPRECATED_WARNINGS
 #  define KITEMVIEWS_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KITEMVIEWS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KITEMVIEWS_DEPRECATED_WARNINGS_SINCE KITEMVIEWS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KITEMVIEWS_DEPRECATED_WARNINGS_SINCE 0x54c00
+#    define KITEMVIEWS_DEPRECATED_WARNINGS_SINCE 0x55200
 #  endif
 #endif
 
@@ -137,5 +137,12 @@
 #define KITEMVIEWS_DEPRECATED_VERSION_5(minor, text)      KITEMVIEWS_DEPRECATED_VERSION_5_##minor(text)
 #define KITEMVIEWS_DEPRECATED_VERSION(major, minor, text) KITEMVIEWS_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
 #define KITEMVIEWS_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KITEMVIEWS_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
+#if defined(__cpp_enumerator_attributes) && __cpp_enumerator_attributes >= 201411
+#  define KITEMVIEWS_ENUMERATOR_DEPRECATED_VERSION(major, minor, text) KITEMVIEWS_DEPRECATED_VERSION(major, minor, text)
+#  define KITEMVIEWS_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KITEMVIEWS_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
+#else
+#  define KITEMVIEWS_ENUMERATOR_DEPRECATED_VERSION(major, minor, text)
+#  define KITEMVIEWS_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
+#endif
 
 #endif /* KITEMVIEWS_EXPORT_H */
